// ZenLib::FileT - Text file manipulation
// Copyright (C) 2002-2003 Jrme Martinez, Zen@MediaArea.net
//
// This software is provided 'as-is', without any express or implied
// warranty.  In no event will the authors be held liable for any damages
// arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented; you must not
//    claim that you wrote the original software. If you use this software
//    in a product, an acknowledgment in the product documentation would be
//    appreciated but is not required.
// 2. Altered source versions must be plainly marked as such, and must not be
//    misrepresented as being the original software.
// 3. This notice may not be removed or altered from any source distribution.
//
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//
// Version 0.0.1
//
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//
// 0.1.0.001 (Zen@MediaArea.net, 2003-06-14)
// Warning : will change in future
//
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

//---------------------------------------------------------------------------
#include <ZenLib/FileT.h>
#include <string.h>
#include <stdio.h>
#include <io.h>
#include <fcntl.h>
#include <sys/stat.h>

#ifdef __UNICODE__
    #include <wx/strconv.h>
    #include <wx/string.h>
    #define fopen _wfopen
#endif

//---------------------------------------------------------------------------

namespace ZenLib
{

//***************************************************************************
// Gestion de la classe
//***************************************************************************

//---------------------------------------------------------------------------
//Constructeur
FileT::FileT ()
{
    F=NULL;
    End=true;
    Nom=_T("");
}

//---------------------------------------------------------------------------
//Destructeur
FileT::~FileT ()
{
    Fermer();
}

//***************************************************************************
// Ouverture/fermeture
//***************************************************************************

//---------------------------------------------------------------------------
//Ouverture du fichier

int FileT::Ouvrir (const Ztring &Fichier, bool Nouveau, bool Ajout, bool Ecriture)
{
    //Si fichier ouvert on ouvre
    Fermer();

    //Ouverture fichier
    if (Nouveau)
        F=fopen(Fichier.c_str(), _T("w+t")); //Nouveau fichier
    else if (Ajout)
        F=fopen(Fichier.c_str(), _T("a+t")); //Veut ecrire en ajout
    else if (Ecriture)
        F=fopen(Fichier.c_str(), _T("r+t")); //Veux ecrire
    else
        F=fopen(Fichier.c_str(), _T("rt"));

    if (!F)
        return -1; //---Si pas de fichier correct

    //Proprietes
    End=false;
    Nom=Fichier;

    return 1;
}

//---------------------------------------------------------------------------
//Fermeture du fichier
void FileT::Fermer ()
{
    //Fermeture
    if (F)
    	fclose(F);

    //Proprits
    F=NULL;
    End=true;
    Nom=_T("");
}

//***************************************************************************
// Texte
//***************************************************************************

//---------------------------------------------------------------------------
//Operation de lecture
Ztring FileT::Lire()
{
    //Test integrite
    if (!F)
        return _T("");

    //Lecture
    char* c=new char[65536];
    char* i=fgets(c, 65536, F);
    Ztring C1=_T("");
    if (i==0)
    {
        //Fin de fichier
        End=true;
    }
    else
    {
		if (c[strlen(c)-1]=='\n')
	        c[strlen(c)-1]=0; //Virer le \n
        #ifdef __UNICODE__
            //C1=wxString(c, wxConvUTF8).c_str();
            C1=wxString(c, wxConvISO8859_1).c_str();
        #else
            C1=c;
        #endif //__UNICODE__
    }
    delete[] c;
    return C1;
}

//---------------------------------------------------------------------------
//opration d'criture
void FileT::Ecrire(const Ztring &Ligne)
{
	//Test integrite
    if (!F)
        return;

	//Ecriture
    #ifdef __UNICODE__
        //std::string LigneUTF8(wxString(Ligne.c_str()).mb_str(wxConvUTF8));
        std::string LigneUTF8(wxString(Ligne.c_str()).mb_str(wxConvISO8859_1));
        fwrite(LigneUTF8.c_str(), 1, LigneUTF8.size(), F);
    #else
        fwrite(Ligne.c_str(), 1, Ligne.size(), F);
    #endif //__UNICODE__
	fwrite("\n", 1, 1, F); //fwrite ecrit \r\n
}

//***************************************************************************
// Divers
//***************************************************************************

//---------------------------------------------------------------------------
//End
bool FileT::Eof()
{
    return End;
}

} //Namespace

